``baseplate.lib.service_discovery``
===================================

.. automodule:: baseplate.lib.service_discovery

.. autoclass:: ServiceInventory
   :members:

.. autoclass:: Backend


Exceptions
----------

.. autoexception:: NoBackendsAvailableError
